@@ -1,8 +1,12 @@
 
 from datetime import datetime, date, time, timedelta
+from fractions import Fraction
 from logging import warning
 from json import JSONEncoder
 from sys import version
+
+from decimal import Decimal
+
 from .utils import hashodict
 
 
@@ -130,6 +134,20 @@ def json_complex_encode(obj):
 	return obj
 
 
+def numeric_types_encode(obj):
+	if isinstance(obj, Decimal):
+		return {
+			'__decimal__': str(obj.canonical()),
+		}
+	if isinstance(obj, Fraction):
+		return {
+			'__fraction__': True,
+			'numerator': obj.numerator,
+			'denominator': obj.denominator,
+		}
+	return obj
+
+
 class ClassInstanceEncoder(JSONEncoder):
 	"""
 	See `class_instance_encoder`.
