@@ -6,9 +6,9 @@ from os import fsync
 from sys import exc_info, version
 from .comment import strip_comment_line_with_symbol, strip_comments  # keep 'unused' imports
 from .encoders import TricksEncoder, json_date_time_encode, class_instance_encode, ClassInstanceEncoder, \
-	json_complex_encode, json_set_encode  # keep 'unused' imports
+	json_complex_encode, json_set_encode, numeric_types_encode  # keep 'unused' imports
 from .decoders import DuplicateJsonKeyException, TricksPairHook, json_date_time_hook, ClassInstanceHook, \
-	json_complex_hook, json_set_hook  # keep 'unused' imports
+	json_complex_hook, json_set_hook, numeric_types_hook  # keep 'unused' imports
 from json import JSONEncoder
 
 
@@ -53,14 +53,14 @@ def json_nonumpy_obj_hook(dct):
 
 
 _cih_instance = ClassInstanceHook()
-DEFAULT_ENCODERS = (json_date_time_encode, class_instance_encode, json_complex_encode, json_set_encode,)
+DEFAULT_ENCODERS = (json_date_time_encode, class_instance_encode, json_complex_encode, json_set_encode, numeric_types_encode,)
 DEFAULT_NONP_ENCODERS = DEFAULT_ENCODERS + (nonumpy_encode,)
-DEFAULT_HOOKS = (json_date_time_hook, _cih_instance, json_complex_hook, json_set_hook,)
+DEFAULT_HOOKS = (json_date_time_hook, _cih_instance, json_complex_hook, json_set_hook, numeric_types_hook,)
 DEFAULT_NONP_HOOKS = (json_nonumpy_obj_hook,) + DEFAULT_HOOKS
 
 
 def dumps(obj, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NONP_ENCODERS, extra_obj_encoders=(),
-		compression=None, **jsonkwargs):
+		compression=None, allow_nan=False, **jsonkwargs):
 	"""
 	Convert a nested data structure to a json string.
 
@@ -69,6 +69,7 @@ def dumps(obj, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NONP_ENCO
 	:param cls: The json encoder class to use, defaults to NoNumpyEncoder which gives a warning for numpy arrays.
 	:param obj_encoders: Iterable of encoders to use to convert arbitrary objects into json-able promitives.
 	:param extra_obj_encoders: Like `obj_encoders` but on top of them: use this to add encoders without replacing defaults. Since v3.5 these happen before default encoders.
+	:param allow_nan: Allow NaN and Infinity values, which is a (useful) violation of the JSON standard (default False).
 	:return: The string containing the json-encoded version of obj.
 
 	Other arguments are passed on to `cls`. Note that `sort_keys` should be false if you want to preserve order.
@@ -76,7 +77,7 @@ def dumps(obj, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NONP_ENCO
 	Use `json_tricks.np.dumps` instead if you want encoding of numpy arrays.
 	"""
 	encoders = tuple(extra_obj_encoders) + tuple(obj_encoders)
-	string = cls(sort_keys=sort_keys, obj_encoders=encoders, **jsonkwargs).encode(obj)
+	string = cls(sort_keys=sort_keys, obj_encoders=encoders, allow_nan=allow_nan, **jsonkwargs).encode(obj)
 	if not compression:
 		return string
 	if compression is True:
@@ -91,7 +92,7 @@ def dumps(obj, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NONP_ENCO
 
 
 def dump(obj, fp, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NONP_ENCODERS, extra_obj_encoders=(),
-		compression=None, force_flush=False, **jsonkwargs):
+		compression=None, force_flush=False, allow_nan=False, **jsonkwargs):
 	"""
 	Convert a nested data structure to a json string.
 
@@ -104,7 +105,7 @@ def dump(obj, fp, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NONP_E
 	Use `json_tricks.np.dump` instead if you want encoding of numpy arrays.
 	"""
 	string = dumps(obj, sort_keys=sort_keys, cls=cls, obj_encoders=obj_encoders, extra_obj_encoders=extra_obj_encoders,
-		compression=compression, **jsonkwargs)
+		compression=compression, allow_nan=allow_nan, **jsonkwargs)
 	if isinstance(fp, str_type):
 		fh = open(fp, 'wb+')
 	else:
@@ -143,6 +144,7 @@ def loads(string, preserve_order=True, ignore_comments=True, decompression=None,
 	:param extra_obj_pairs_hooks: Like `obj_pairs_hooks` but on top of them: use this to add hooks without replacing defaults. Since v3.5 these happen before default hooks.
 	:param cls_lookup_map: If set to a dict, for example ``globals()``, then classes encoded from __main__ are looked up this dict.
 	:param allow_duplicates: If set to False, an error will be raised when loading a json-map that contains duplicate keys.
+	:param parse_float: A function to parse strings to integers (e.g. Decimal). There is also `parse_int`.
 	:return: The string containing the json-encoded version of obj.
 
 	Other arguments are passed on to json_func.
