@@ -27,7 +27,7 @@ def numpy_encode(obj):
 	if isinstance(obj, ndarray):
 		dct = hashodict((
 			('__ndarray__', obj.tolist()),
-		    ('dtype', str(obj.dtype)),
+			('dtype', str(obj.dtype)),
 			('shape', obj.shape),
 		))
 		if len(obj.shape) > 1:
@@ -71,11 +71,8 @@ def json_numpy_obj_hook(dct):
 		if dct['shape']:
 			return asarray(dct['__ndarray__'], dtype=dct['dtype'], order=order)
 		else:
-			# print(dct['dtype'])
-			# print(getattr(nptypes, dct['dtype']))
 			dtype = getattr(nptypes, dct['dtype'])
 			return dtype(dct['__ndarray__'])
-			# return asarray(dct['__ndarray__'], dtype=dct['dtype'], order=order)
 	return dct
 
 
@@ -84,21 +81,24 @@ DEFAULT_NP_HOOKS = (json_numpy_obj_hook,) + DEFAULT_HOOKS
 
 
 def dumps(obj, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NP_ENCODERS,
-		extra_obj_encoders=(), compression=None, **jsonkwargs):
+		extra_obj_encoders=(), compression=None, allow_nan=False, **jsonkwargs):
 	"""
 	Just like `nonp.dumps` but with numpy functionality enabled.
 	"""
 	return nonp.dumps(obj, sort_keys=sort_keys, cls=cls, obj_encoders=obj_encoders,
-		extra_obj_encoders=extra_obj_encoders, compression=compression, **jsonkwargs)
+		extra_obj_encoders=extra_obj_encoders, compression=compression,
+		allow_nan=allow_nan, **jsonkwargs)
 
 
-def dump(obj, fp, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NP_ENCODERS, extra_obj_encoders=(),
-		compression=None, force_flush=False, **jsonkwargs):
+def dump(obj, fp, sort_keys=None, cls=TricksEncoder, obj_encoders=DEFAULT_NP_ENCODERS,
+		extra_obj_encoders=(), compression=None, force_flush=False, allow_nan=False,
+		**jsonkwargs):
 	"""
 	Just like `nonp.dump` but with numpy functionality enabled.
 	"""
 	return nonp.dump(obj, fp, sort_keys=sort_keys, cls=cls, obj_encoders=obj_encoders,
-		extra_obj_encoders=extra_obj_encoders, compression=compression, force_flush=force_flush, **jsonkwargs)
+		extra_obj_encoders=extra_obj_encoders, compression=compression,
+		force_flush=force_flush, allow_nan=allow_nan, **jsonkwargs)
 
 
 def loads(string, preserve_order=True, ignore_comments=True, decompression=None, obj_pairs_hooks=DEFAULT_NP_HOOKS,
